# eric7.PdfViewer.PdfInfoWidget

Module implementing an info widget showing data of a PDF document.

### Global Attributes

None

### Classes

PdfInfoWidget | Class implementing an info widget showing data of a PDF document.

### Functions

None

## PdfInfoWidget

Class implementing an info widget showing data of a PDF document.

### Derived from

QWidget

### Class Attributes

None

### Class Methods

None

### Methods

PdfInfoWidget | Constructor
__handlePageCountChanged | Private slot to handle a change of the page count.
__handlePasswordChanged | Private slot to handle a change of the password.
__populateInfoLabels | Private slot to populate the info labels upon a change of the document status.
setDocument | Public method to set the reference to the PDF document.
setFileName | Public method to set the file name info.

### Static Methods

None

#### PdfInfoWidget (Constructor)

PdfInfoWidget(document, parent=None)

Constructor

document (QPdfDocument)
  reference to the PDF document object
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### PdfInfoWidget.__handlePageCountChanged

__handlePageCountChanged(pageCount)

Private slot to handle a change of the page count.

pageCount (int)
  changed page count

#### PdfInfoWidget.__handlePasswordChanged

__handlePasswordChanged()

Private slot to handle a change of the password.

#### PdfInfoWidget.__populateInfoLabels

__populateInfoLabels(status)

Private slot to populate the info labels upon a change of the document status.

status (QPdfDocument.Status)
  document status

#### PdfInfoWidget.setDocument

setDocument(document)

Public method to set the reference to the PDF document.

document (QPdfDocument)
  reference to the document

#### PdfInfoWidget.setFileName

setFileName(filename)

Public method to set the file name info.

filename (TYPE)
  DESCRIPTION

Up